@@ -3,7 +3,7 @@ package BorderStyle::ASCII::SingleLineVerticalOnly;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-06-11'; # DATE
 our $DIST = 'BorderStyles-Standard'; # DIST
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 use strict;
 use parent 'BorderStyleBase';
@@ -36,7 +36,38 @@ BorderStyle::ASCII::SingleLineVerticalOnly - Single line border with ASCII chara
 
 =head1 VERSION
 
-This document describes version 0.001 of BorderStyle::ASCII::SingleLineVerticalOnly (from Perl distribution BorderStyles-Standard), released on 2020-06-11.
+This document describes version 0.002 of BorderStyle::ASCII::SingleLineVerticalOnly (from Perl distribution BorderStyles-Standard), released on 2020-06-11.
+
+=head1 SYNOPSIS
+
+To use with L<Text::Table::TinyBorderStyle>:
+
+ use Text::Table::TinyBorderStyle qw/generate_table/;
+ my $rows =
+   [
+     ["ColumName1", "ColumnNameB", "ColumnNameC"],
+     ["row1A", "row1B", "row1C"],
+     ["row2A", "row2B", "row2C"],
+     ["row3A", "row3B", "row3C"],
+   ];
+ generate_table(rows=>$rows, header_row=>1, separate_rows=>1, border_style=>"BorderStyle::ASCII::SingleLineVerticalOnly");
+
+Sample output:
+
+ |            |             |             |
+ | ColumName1 | ColumnNameB | ColumnNameC |
+ |            |             |             |
+ | row1A      | row1B       | row1C       |
+ |------------|-------------|-------------|
+ | row2A      | row2B       | row2C       |
+ |------------|-------------|-------------|
+ | row3A      | row3B       | row3C       |
+ |            |             |             |
+
+
+To use with L<Text::ANSITable>:
+
+ # TODO
 
 =head1 HOMEPAGE
 
