@@ -3,7 +3,7 @@ package BorderStyle::UTF8::None;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-06-11'; # DATE
 our $DIST = 'BorderStyles-Standard'; # DIST
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 use strict;
 use parent 'BorderStyleBase';
@@ -38,7 +38,35 @@ BorderStyle::UTF8::None - No borders, but data row separator is still drawn usin
 
 =head1 VERSION
 
-This document describes version 0.001 of BorderStyle::UTF8::None (from Perl distribution BorderStyles-Standard), released on 2020-06-11.
+This document describes version 0.002 of BorderStyle::UTF8::None (from Perl distribution BorderStyles-Standard), released on 2020-06-11.
+
+=head1 SYNOPSIS
+
+To use with L<Text::Table::TinyBorderStyle>:
+
+ use Text::Table::TinyBorderStyle qw/generate_table/;
+ my $rows =
+   [
+     ["ColumName1", "ColumnNameB", "ColumnNameC"],
+     ["row1A", "row1B", "row1C"],
+     ["row2A", "row2B", "row2C"],
+     ["row3A", "row3B", "row3C"],
+   ];
+ generate_table(rows=>$rows, header_row=>1, separate_rows=>1, border_style=>"BorderStyle::UTF8::None");
+
+Sample output:
+
+  ColumName1  ColumnNameB  ColumnNameC 
+  row1A       row1B        row1C       
+ ────────────────────────────────────────
+  row2A       row2B        row2C       
+ ────────────────────────────────────────
+  row3A       row3B        row3C       
+
+
+To use with L<Text::ANSITable>:
+
+ # TODO
 
 =head1 HOMEPAGE
 
